@@ -99,11 +99,13 @@ void openssl_init() {
     if(!SSLWantReadError) goto cleanup;
 
 #if defined(_WIN32) || defined(__CYGWIN__)
+#ifdef _M_ARM64
+    HMODULE windows_openssl_handle = GetModuleHandle(TEXT("libssl-3-arm64.dll"));
+#else
     HMODULE windows_openssl_handle = GetModuleHandle(TEXT("libssl-3.dll"));
-    if(!windows_openssl_handle) {
-        windows_openssl_handle = GetModuleHandle(TEXT("libssl-1_1.dll"));
-        if(!windows_openssl_handle) goto cleanup;
-    }
+    if(!windows_openssl_handle) windows_openssl_handle = GetModuleHandle(TEXT("libssl-1_1.dll"));
+#endif
+    if(!windows_openssl_handle) goto cleanup;
 
     *(void**)&SSL_read_ex = GetProcAddress(windows_openssl_handle, "SSL_read_ex");
     *(void**)&SSL_get_error = GetProcAddress(windows_openssl_handle, "SSL_get_error");
@@ -111,10 +113,12 @@ void openssl_init() {
 #else
     // Find library at "import ssl; print(ssl._ssl.__file__)"
 
-    _ssl_module_path = PyObject_GetAttrString(_ssl_module, "__file__");
-    if(!_ssl_module_path) goto error;
+    if (PyObject_HasAttrString(_ssl_module, "__file__")) {
+        _ssl_module_path = PyObject_GetAttrString(_ssl_module, "__file__");
+        if(!_ssl_module_path) goto error;
+        openssl_handle = dlopen(PyUnicode_AsUTF8(_ssl_module_path), RTLD_LAZY | RTLD_NOLOAD);
+    }
 
-    openssl_handle = dlopen(PyUnicode_AsUTF8(_ssl_module_path), RTLD_LAZY | RTLD_NOLOAD);
     if(!openssl_handle) goto error;
 
     *(void**)&SSL_read_ex = dlsym(openssl_handle, "SSL_read_ex");
